@@ -7,7 +7,7 @@ package Spreadsheet::WriteExcel::Workbook;
 #
 # Used in conjunction with Spreadsheet::WriteExcel
 #
-# Copyright 2000-2003, John McNamara, jmcnamara@cpan.org
+# Copyright 2000-2004, John McNamara, jmcnamara@cpan.org
 #
 # Documentation after __END__
 #
@@ -1339,6 +1339,6 @@ John McNamara jmcnamara@cpan.org
 
 =head1 COPYRIGHT
 
- MM-MMIII, John McNamara.
+ MM-MMIV, John McNamara.
 
 All Rights Reserved. This module is free software. It may be used, redistributed and/or modified under the same terms as Perl itself.
